@@ -1,7 +1,8 @@
 import os
 
 
-from impact_factor.util.webrequest import WebRequest
+from webrequests import WebRequest
+
 
 BASE_URL = 'https://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi'
 API_KEY = os.getenv('NCBI_API_KEY')
